# doas

This project contains utility modules and libraries to process DOAS data.

## Installation

Install the latest version from PyPI by typing this command:

    pip install -U doas

## Documentation

Full documentation and tutorials are available at `docs/` directory.

## Contributing

See `CONTRIBUTING.md` to learn how to contribute to this project.

## Support

This project is maintained by Indra Rudianto. If you have any question about
this project, you can contact him at <indrarudianto.official@gmail.com>.

## License

By contributing to the project, you agree that your contributions will be
licensed under its MIT license.
See [LICENSE](https://gitlab.com/bpptkg/doas/-/blob/master/LICENSE) for details.
